@@ -8,3 +8,8 @@ class Store:
         raise NotImplementedError(
             "set_customer_data() must be implemented by subclasses"
         )
+
+    def set_customer_feature_value(self, customer_id, key, value):
+        raise NotImplementedError(
+            "set_customer_feature_value() must be implemented by subclasses"
+        )
